Name:       psi
Version:    0.14
Release:    8%{?dist}
Summary:    Jabber client based on Qt
License:    GPLv2+
Group:      Applications/Internet
URL:        http://psi-im.org
Source0:    http://dl.sf.net/psi/psi-%{version}.tar.bz2
Patch0:     psi-0.12-qca.patch
# The following two patches are from the git version - they can 
# be dropped on the next upstream release
Patch1:     psi-0.14-configureroomcrash.patch
Patch2:     psi-0.14-affiliationlistconfigmuc.patch
# Fix QLabel CVE - rhbz 746877
Patch3:     psi-0.14-input-validation.patch
# Fix build with gcc 4.7 - patch is already in upstream git
Patch4:     psi-0.14-gcc-47.patch

BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  qt4-devel, zlib-devel, desktop-file-utils
BuildRequires:  qca2-devel, glib2-devel
BuildRequires:  enchant-devel, libXScrnSaver-devel

Requires: sox
Requires: gnupg
# Required for SSL/TLS connections
Requires: qca-ossl%{?_isa}
# Required for GnuPG encryption
Requires: qca-gnupg%{?_isa}
# minimal qt4 runtime dep
%{?_qt4_version:Requires: qt4%{?_isa} >= %{_qt4_version}}

# Language packs
Source10:   psi-lang-packs-0.13-1.tar.gz

# Iconsets
Source11:   emoticons-0.10.tar.gz
Source12:   rostericons-0.10.tar.gz
#Source13:   systemicons-0.9.3.tar.gz



%description
Psi is the premiere Instant Messaging application designed for Microsoft
Windows, Apple Mac OS X and GNU/Linux. Built upon an open protocol named
Jabber, Psi is a fast and lightweight messaging client that utilises the best
in open source technologies. Psi contains all the features necessary to chat,
with no bloated extras that slow your computer down. The Jabber protocol
provides gateways to other protocols as AIM, ICQ, MSN and Yahoo!.
If you want SSL support, install the qca-tls package.

%package -n %name-i18n
Summary:    Language packs for Psi
Group:      Applications/Internet
Requires:   psi = %version

%description -n %name-i18n
This package adds internationalization to Psi.
If you want to add a translation from http://psi-im.org,
just put the .qm file in %_datadir/%name (you'll have to do
this as root), and restart psi.

%package -n %name-icons
Summary:    Additional icons for Psi
Group:      Applications/Internet
Requires:   psi >= 0.9.1

%description -n %name-icons
This package contains additional icons for Psi
There are three types of icons:
- emoticons, also known as smileys
- roster icons, to change the appearance of Psi's main window
- system icons, to change the rest of Psi's icons
More icons can be found on http://jisp.netflint.net


%prep
%setup -q
%patch0 -p1 -b .qca
%patch1 -p1 -b .configureroom
%patch2 -p1 -b .affiliationlistmuc
%patch3 -p0 -b .qlabelcve
%patch4 -p0 -b .gccbuild

%build
unset QTDIR
./configure                        \
        --prefix=%{_prefix}        \
        --bindir=%{_bindir}        \
        --libdir=%{_libdir}        \
        --datadir=%{_datadir}      \
        --disable-bundled-qca      \
        --disable-aspell           \
        --debug                    \
        --no-separate-debug-info

echo "DEFINES += QT_NO_DEBUG" >> conf.pri

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT

export INSTALL_ROOT=$RPM_BUILD_ROOT
make install

# Install language packs
tar -xzpf %{SOURCE10} -C $RPM_BUILD_ROOT%{_datadir}/%name/
rm -f $RPM_BUILD_ROOT%{_datadir}/%name/getlangs.sh
rm -f $RPM_BUILD_ROOT%{_bindir}/psi.debug

## Install iconsets
tar -xzpf %{SOURCE11} -C $RPM_BUILD_ROOT%{_datadir}/%name/iconsets/emoticons/
tar -xzpf %{SOURCE12} -C $RPM_BUILD_ROOT%{_datadir}/%name/iconsets/roster/
#tar -xzpf %{SOURCE13} -C $RPM_BUILD_ROOT%{_datadir}/%name/iconsets/system/

# Menu
%if 0%{?fedora} < 15
desktop-file-install --vendor fedora \
       --dir $RPM_BUILD_ROOT%{_datadir}/applications\
       --delete-original\
       $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop
%endif

mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}/plugins

%check
%if 0%{?fedora} > 14
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
touch --no-create %{_datadir}/icons/hicolor &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
  touch --no-create %{_datadir}/icons/hicolor &> /dev/null
  gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :

%files
%defattr(0644,root,root,0755)
%doc README COPYING
%attr(0755,root,root) %{_bindir}/psi
#%attr(0755,root,root) %{_bindir}/psi.debug
%{_datadir}/%{name}
%_datadir/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/%name.png
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/plugins/
%exclude %{_datadir}/%{name}/*.qm
%exclude %{_datadir}/%{name}/iconsets/*/*.jisp

%files -n %name-i18n
%defattr(0644,root,root,0755)
%{_datadir}/%name/%{name}_*.qm


%files -n %name-icons
%defattr(0644,root,root,0755)
%{_datadir}/%name/iconsets/*/*.jisp


%changelog
* Sat Jan 07 2012 Sven Lankes <sven@lank.es> 0.14-8
- fix compile with gcc 4.7.0

* Sun Nov 27 2011 Sven Lankes <sven@lank.es> 0.14-7
- Change certificate ui to use plain-text fields to avoid security
    issue with qlabel. rhbz #746877

* Wed Mar 16 2011 Rex Dieter <rdieter@fedoraproject.org> 0.14-6
- fix FTBFS (drop Requires(hint) usage)
- make qca plugin deps arched
- add arched/versioned qt4 runtime dep
- update scriptlets
- drop desktop-file-install --vendor usage (f15+)

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan 17 2011 Sven Lankes <sven@lank.es> 0.14-4
- Don't crash in chat room configuration dialog (rhbz #668850)

* Thu Apr 08 2010 Aurelien Bompard <abompard@fedoraproject.org> -  0.14-3
- disable debug, but don't break the -debuginfo pkg (rhbz#579131)

* Sun Apr 04 2010 Aurelien Bompard <abompard@fedoraproject.org> -  0.14-2
- disable debug (rhbz#579131)

* Thu Dec 03 2009 Aurelien Bompard <abompard@fedoraproject.org> -  0.14-1
- 0.14 final
- patch1 merged upstream

* Sun Nov 29 2009 Sven Lankes <sven@lank.es> 0.14-0.2.rc3
- Add (upstream) patch to make enchant spelling-suggestions work
- Remove old patches

* Sun Nov 29 2009 Sven Lankes <sven@lank.es> 0.14-0.1.rc3
- 0.14 rc3

* Mon Nov 09 2009 Aurelien Bompard <abompard@fedoraproject.org> -  0.14-0.1.rc1
- 0.14 rc1

* Tue Jul 28 2009 Aurelien Bompard <abompard@fedoraproject.org> - 0.13-1
- 0.13 final

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-0.3.rc4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 17 2009 Sven Lankes <sven@lank.es> 0.13-0.2.rc4
- 0.13 rc4

* Mon Jul 13 2009 Sven Lankes <sven@lank.es> 0.13-0.2.rc3
- 0.13 rc3
- remove qt 4.5 patch

* Thu Jul 05 2009 Sven Lankes <sven@lank.es> 0.13-0.2.rc2
- own plugin directories (bz #509683)

* Thu Jul 02 2009 Sven Lankes <sven@lank.es> 0.13-0.1.rc2
- 0.13 rc2

* Sun May 24 2009 Aurelien Bompard <abompard@fedoraproject.org> 0.13-0.1.rc1
- 0.13 rc1

* Sat Mar 28 2009 Sven Lankes <sven@lank.es> 0.12.1-2
- bump Version to avoid newer EVR in F9/F10

* Tue Mar 03 2009 Sven Lankes <sven@lank.es> 0.12.1-1
- Update to 0.12.1 (fix for CVE-2008-6393)
- add patch for qt 4.5 support

* Sun Mar 01 2009 Robert Scheck <robert@fedoraproject.org> 0.12-3
- Added missing build requirement to glib2-devel

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Aug 13 2008 Aurelien Bompard <abompard@fedoraproject.org> 0.12-1
- version 0.12

* Wed May 21 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.11-5
- fix license tag

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.11-4
- Autorebuild for GCC 4.3

* Sat Nov 24 2007 Aurelien Bompard <abompard@fedoraproject.org> 0.11-3
- Require qca-gnupg for GnuPG support

* Wed Oct 17 2007 Aurelien Bompard <abompard@fedoraproject.org> 0.11-1
- version 0.11

* Wed Aug 30 2006 Aurelien Bompard <abompard@fedoraproject.org> 0.10-5
- rebuild

* Thu Apr 13 2006 Aurelien Bompard <gauret[AT]free.fr> 0.10-4
- update translations for CS, DE, ET and VI

* Tue Feb 21 2006 Aurelien Bompard <gauret[AT]free.fr> 0.10-3
- rebuild for FC5

* Thu Jan 12 2006 Aurelien Bompard <gauret[AT]free.fr> 0.10-1
- version 0.10 final

* Tue Jan 03 2006 Aurelien Bompard <gauret[AT]free.fr> 0.10-0.3.test4
- version 0.10 test4

* Thu Nov 03 2005 Aurelien Bompard <gauret[AT]free.fr> 0.10-0.2.test3
- version 0.10 test3

* Sat Oct 15 2005 Aurelien Bompard <gauret[AT]free.fr> 0.10-0.2.test2
- version 0.10 test2
- drop patch 3 (applied upstream)
- drop icon symlink (useless)

* Thu Aug 25 2005 Aurelien Bompard <gauret[AT]free.fr> 0.10-0.1.test1
- version 0.10 test1
- spec cleanups

* Wed Jun  1 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 0.9.3-4
- patch it for 64-bit/GCC 4

* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 0.9.3-3
- rebuild on all arches

* Thu Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 0.9.3-2
- rebuilt

* Sun Jan 09 2005 Aurelien Bompard <gauret[AT]free.fr> 0:0.9.3-1
- version 0.9.3 final

* Mon Jan 03 2005 Aurelien Bompard <gauret[AT]free.fr> 0:0.9.3-0.fdr.0.3.test2
- version 0.9.3-test2

* Thu Nov 25 2004 Aurelien Bompard <gauret[AT]free.fr> 0:0.9.3-0.fdr.0.2.test1
- Drop hardcoded requirement on qca-tls, it should be a plugin

* Mon Nov 22 2004 Aurelien Bompard <gauret[AT]free.fr> 0:0.9.3-0.fdr.0.1.test1
- update to 0.9.3test1
- use the provided icon in the menu and drop Source1.
- add crystal iconset
- added Russian and Eesti translations

* Sat Sep 18 2004 Aurelien Bompard <gauret[AT]free.fr> 0:0.9.2-0.fdr.3
- add patch for typing notification
- add crystal iconset
- update translations (adding kiswahili and Eesti)

* Fri Jun 11 2004 Aurelien Bompard <gauret[AT]free.fr> 0:0.9.2-0.fdr.2
- split qca-tls out of this package and require it
- fix build on FC1

* Thu Jun 10 2004 Aurelien Bompard <gauret[AT]free.fr> 0:0.9.2-0.fdr.1
- version 0.9.2
- drop libgnome patch, psi now uses gnome-open
- rediffed the other patches

* Sat Feb 28 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.9
- add a patch to build with mach
- removed URLs in iconsets because the website changed
- add one iconset

* Tue Feb 17 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.8
- add a patch from Debian
- avoid stripping of binary

* Sat Feb 14 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.7
- add German (de) and Simplified Chinese (zh) translations
- Apply suggestions from Michael Schwendt :
  - BuildRequies kdelibs-devel if built --with kde
  - Drop rostericonset "neos" because it is buggy
  - Put docs in %%_datadir/psi to avoid empty about box
  - Fix source URL
  - Fix files list for FC2

* Mon Feb 09 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.6
- add Cesky (cs) and Catalan (ca) translations

* Sat Jan 31 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.5
- add polish (pl) translation.
- improve description of the i18n package

* Wed Jan 28 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.4
- add spanish (es) and svenska (se) translations.
- *really* add GNOME icon...

* Tue Jan 27 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.3
- add slovak (sk) and italian (it) translations.

* Tue Jan 20 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.2
- add GNOME icon

* Sun Jan 11 2004 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9.1-0.fdr.1
- version 0.9.1
- add jisp emoticons in a separate package (psi-icons)
- add ICONSET-HOWTO
- drop old iconsets (and thus remove buildrequires: unzip)
- add rebuild option "--without kde" to prepare for future version of psi
  which will take this into account. Right now it is ignored.

* Sat Nov 22 2003 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9-0.fdr.4
- add Requires: sox to play sound (thanks to you-know-who ;-) )
- fix date in changelog.

* Fri Nov 21 2003 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9-0.fdr.3
- Thanks to Michael Schwendt (again :-) ) :
  * exclude lang files from main package
  * preserve timestamps when possible
  * fix .desktop file
  * add ssl support

* Tue Nov 18 2003 Aurelien Bompard <gauret[AT]free.fr> - 0:0.9-0.fdr.2
- Thanks to Michael Schwendt :
  * group language packs into one subpackage.
  * added epoch=0
  * added environnement variables to ./configure
  * added BuildRequires: XFree86-devel

* Wed Nov 12 2003 Aurelien Bompard <gauret[AT]free.fr> - 0.9-0.fdr.1
- port to Fedora (from Mandrake)
